Documentation
¶
Index ¶
- func GetEmptyDocx() ([]byte, error)
- func GetEmptyPptx() ([]byte, error)
- func GetEmptyXlsx() ([]byte, error)
- func GetTemplateForExtension(ext string) ([]byte, error)
- func Render(w io.Writer, name string, data interface{}) error
- func RenderString(name string, data interface{}) (string, error)
- type LoginSuccessData
- type OnlyOfficeData
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func GetEmptyDocx ¶
GetEmptyDocx returns a minimal valid .docx file that OnlyOffice can edit
func GetEmptyPptx ¶
GetEmptyPptx returns a minimal valid .pptx file that OnlyOffice can edit
func GetEmptyXlsx ¶
GetEmptyXlsx returns a minimal valid .xlsx file that OnlyOffice can edit
func GetTemplateForExtension ¶
GetTemplateForExtension returns the appropriate template for a file extension Returns nil, nil if no template is needed (file can be empty)
func Render ¶
Render executes the named page template with data, rendering through the base layout. The template is invoked via the "base" block defined in base.html.
func RenderString ¶
RenderString is like Render but returns the result as a string.
Types ¶
type LoginSuccessData ¶
type LoginSuccessData struct {
ReturnURL string
}
LoginSuccessData holds data for login_success.html
Click to show internal directories.
Click to hide internal directories.